@@ -40,15 +40,11 @@ sub internal_redirect {
 
 	my $url = $_[0];
 	
-#print STDERR "URL: $url ";
-	
 	unless ($url =~ /^http:\/\//) {
 		$url =~ s{^/}{};
 		$url = "http://$ENV{HTTP_HOST}/$url" ;
 	}
 
-#print STDERR " --> $url\n";
-
 	print $q -> redirect (-uri => $url);
 	
 }
@@ -78,6 +74,21 @@ sub content_type {
 
 ################################################################################
 
+sub content_encoding {
+
+	my $self = shift;
+	my $q = $self -> {Q};
+
+	if ($_ [0]) {
+		$self -> {Out_headers} -> {-content_encoding} = $_ [0];
+	} else {
+		return $self -> {Out_headers} -> {-content_encoding};
+	}
+	
+}
+
+################################################################################
+
 sub status {
 
 	my $self = shift;
@@ -221,6 +232,7 @@ sub uri {
 ################################################################################
 
 sub header_only {
+	my $self = shift;
 	return $self -> {Q} -> request_method () eq 'HEAD';
 }
 
